@@ -25,9 +25,10 @@ class Client:
         lb_enable_experimental=False, lb_app_url="https://app.labelbox.com"):
         self.lb_client = labelboxClient(lb_api_key, endpoint=lb_endpoint, enable_experimental=lb_enable_experimental, app_url=lb_app_url)
     
-    def create_data_rows_from_table(self, spark_table, lb_dataset, row_data_col, global_key_col=None, external_id_col=None, metadata_index={}, batch_size=20000):
+    def create_data_rows_from_table(self, lb_client, spark_table, lb_dataset, row_data_col, global_key_col=None, external_id_col=None, metadata_index={}, batch_size=20000):
         """ Creates Labelbox data rows given a Spark Table and a Labelbox Dataset. Requires user to specify which columns correspond to which data row values.
         Args:
+            lb_client           :   Required( labelbox.client.Client) - Labelbox Client object        
             spark_table         :   Required (pyspark.sql.dataframe.Dataframe) - Spark Table
             lb_dataset          :   Required (labelbox.schema.dataset.Dataset) - Labelbox dataset to add data rows to
             row_data_col        :   Required (str) - Column name for the data row row data URL
@@ -59,25 +60,25 @@ class Client:
         # Create a spark_table with a new "uploads" column that can be queried as a list of dictionaries and uploaded to Labelbox
         starttime = datetime.now()
         uploads_table = connector.create_uploads_column(
-            lb_client=self.lb_client,
+            lb_client=lb_client,
             spark_table=spark_table,
             row_data_col=row_data_col,
             global_key_col=global_key_col,
             external_id_col=external_id_col,
             metadata_index=metadata_index)
         endtime = datetime.now()
-        print(f'Success: Labelbox upload conversion complete\nStart Time: {starttime}\nEnd Time: {endtime}\n Conversion Time: {starttime-endtime}\nData Rows to Upload: {len(uploads_pandas)}')
+        print(f'Success: Labelbox upload conversion complete\n Start Time: {starttime}\n End Time: {endtime}\n Conversion Time: {endtime-starttime}\nData Rows to Upload: {len(uploads_pandas)}')
         # Query your table and create a dictionary where {key=global_key : value=data_row_dict to-be-uploaded to Labelbox}
         starttime = datetime.now()
         upload_list = uploads_table.select("uploads").rdd.map(lambda x: x.uploads.asDict()).collect()
         global_key_to_upload_dict = {data_row_dict['global_key'] : data_row_dict for data_row_dict in upload_list}
         # Batch upload data rows from your global_key_to_upload_dict
         upload_results = connector.batch_create_data_rows(
-            client=self.lb_client, 
+            client=lb_client, 
             dataset=lb_dataset, 
             global_key_to_upload_dict=global_key_to_upload_dict)
         endtime = datetime.now()
-        print(f'Success: Uploaded table rows to Labelbox dataset with ID {lb_dataset.uid}\nStart Time: {starttime}\nEnd Time: {endtime}\n Upload Time: {starttime-endtime}\nData rows uploaded: {len(uploads_pandas)}')
+        print(f'Success: Uploaded table rows to Labelbox dataset with ID {lb_dataset.uid}\n Start Time: {starttime}\n End Time: {endtime}\n Upload Time: {endtime-starttime}\nData rows uploaded: {len(uploads_pandas)}')
         return upload_results
 
     def create_table_from_dataset(self, lb_client, lb_dataset, metadata_index={}):
@@ -96,7 +97,7 @@ class Client:
         starttime = datetime.now()
         data_rows_list = list(lb_dataset.export_data_rows(include_metadata=True)) if metadata_fields else list(lb_dataset.export_data_rows(include_metadata=False))
         endtime = datetime.now()
-        print(f'Labelbox data row export complete\nStart Time: {starttime}\nEnd Time: {endtime}\n Export Time: {starttime-endtime}\nData rows to create in table: {len(data_rows_list)}')
+        print(f'Labelbox data row export complete\n Start Time: {starttime}\n End Time: {endtime}\n Export Time: {endtime-starttime}\nData rows to create in table: {len(data_rows_list)}')
         starttime = datetime.now()
         metadata_schema_to_name_key = connector.get_metadata_schema_to_name_key(lb_client.get_data_row_metadata_ontology())
         # Create empty dict where {key= column name : value= list of values for column} (in order)
@@ -123,12 +124,13 @@ class Client:
                     table_dict[metadata_name].append(metadata_dict[metadata_name])
         return_spark_table = pd.DataFrame.from_dict(table_dict).to_spark()
         endtime = datetime.now()
-        print(f'Success: Created table from Labelbox dataset with ID {lb_dataset.uid}\nStart Time: {starttime}\nEnd Time: {endtime}\n Total Time: {starttime-endtime}\nData rows in table: {len(data_rows_list)}')
+        print(f'Success: Created table from Labelbox dataset with ID {lb_dataset.uid}\n Start Time: {starttime}\n End Time: {endtime}\n Total Time: {endtime-starttime}\nData rows in table: {len(data_rows_list)}')
         return return_spark_table
     
-    def upsert_table_metadata(self, spark_table, global_key_col, global_keys_list=[], metadata_index={}):
+    def upsert_table_metadata(self, lb_client, spark_table, global_key_col, global_keys_list=[], metadata_index={}):
         """ Upserts a Spark Table based on the most recent metadata in Labelbox, only upserts columns provided via metadata_fields list
         Args:
+            lb_client           :   Required( labelbox.client.Client) - Labelbox Client object            
             spark_table         :   Required (pyspark.sql.dataframe.Dataframe) - Spark Table
             lb_dataset          :   Required (labelbox.schema.dataset.Dataset) - Labelbox dataset to add data rows to
             global_key_col      :   Required (str) - Global key column name to map Labelbox data rows to the Databricks spark table rows
@@ -138,17 +140,17 @@ class Client:
             Upserted Spark table
         """
         starttime = datetime.now()
-        lb_mdo = self.lb_client.get_data_row_metadata_ontology()
+        lb_mdo = lb_client.get_data_row_metadata_ontology()
         metadata_schema_to_name_key = connector.get_metadata_schema_to_name_key(lb_mdo)
         metadata_fields = list(metadata_index.keys())
         # Either use global_keys provided or all the global keys in the provided global_key column 
         global_keys = global_keys_list if global_keys_list else [str(x.__getitem__(global_key_col)) for x in spark_table.select(global_key_col).distinct().collect()]
         # Grab data row IDs with global_key list
-        data_row_ids = self.lb_client.get_data_row_ids_for_global_keys(global_keys)['results']
+        data_row_ids = lb_client.get_data_row_ids_for_global_keys(global_keys)['results']
         # Get data row metadata with list of data row IDs
         data_row_metadata = lb_mdo.bulk_export(data_row_ids)
         endtime = datetime.now()
-        print(f'Laeblbox metadata export complete\nStart Time: {starttime}\nEnd Time: {endtime}\n Export Time: {starttime-endtime}\nData rows in export: {len(data_row_metadata)}')        
+        print(f'Laeblbox metadata export complete\n Start Time: {starttime}\n End Time: {endtime}\n Export Time: {endtime-starttime}\nData rows in export: {len(data_row_metadata)}')        
         starttime = datetime.now()
         # Dict where metadata_field_name : global_key : metadata_field_value (for enums, is the schema ID)
         upsert_dict = {}
@@ -169,12 +171,13 @@ class Client:
                 global_key_col=global_key_col, 
                 metadata_value_col=metadata_field_name))
         endtime = datetime.now()
-        print(f'Upsert table metadata complete\nStart Time: {starttime}\nEnd Time: {endtime}\n Total Time: {starttime-endtime}\nData rows upserted: {len(data_row_metadata)}') 
+        print(f'Upsert table metadata complete\n Start Time: {starttime}\n End Time: {endtime}\n Total Time: {endtime-starttime}\nData rows upserted: {len(data_row_metadata)}') 
         return spark_table
 
-    def upsert_labelbox_metadata(self, spark_table, global_key_col, global_keys_list=[], metadata_fields=[]):
+    def upsert_labelbox_metadata(self, lb_client, spark_table, global_key_col, global_keys_list=[], metadata_fields=[]):
         """ Updates Labelbox data row metadata based on the most recent metadata from a Databricks spark table, only updates metadata fields provided via a metadata_index keys
         Args:
+            lb_client           :   Required( labelbox.client.Client) - Labelbox Client object                    
             spark_table         :   Required (pyspark.sql.dataframe.Dataframe) - Spark Table
             lb_dataset          :   Required (labelbox.schema.dataset.Dataset) - Labelbox dataset to add data rows to
             global_key_col      :   Required (str) - Global key column name to map Labelbox data rows to the Databricks spark table rows
@@ -183,13 +186,13 @@ class Client:
         Returns:
             List of errors from metadata ontology bulk upsert - if successful, is an empty list
         """
-        lb_mdo = self.lb_client.get_data_row_metadata_ontology()
+        lb_mdo = lb_client.get_data_row_metadata_ontology()
         metadata_schema_to_name_key = connector.get_metadata_schema_to_name_key(lb_mdo)
         metadata_name_key_to_schema = connector.get_metadata_schema_to_name_key(lb_mdo, invert=True)
         # Either use global_keys provided or all the global keys in the provided global_key_col
         global_keys = global_keys_list if global_keys_list else [str(x.__getitem__(global_key_col)) for x in spark_table.select(global_key_col).distinct().collect()]
         # Grab data row IDs with global_key list
-        data_row_ids = self.lb_client.get_data_row_ids_for_global_keys(global_keys)['results']
+        data_row_ids = lb_client.get_data_row_ids_for_global_keys(global_keys)['results']
         # Get data row metadata with list of data row IDs
         data_row_metadata = lb_mdo.bulk_export(data_row_ids)  
         upload_metadata = []  
