@@ -12,7 +12,7 @@ def refresh_metadata_ontology(client):
         lb_mdo              :   labelbox.schema.data_row_metadata.DataRowMetadataOntology
         lb_metadata_names   :   List of metadata field names from a Labelbox metadata ontology
     """
-    lb_mdo = client.lb_client.get_data_row_metadata_ontology()
+    lb_mdo = client.get_data_row_metadata_ontology()
     lb_metadata_names = [field['name'] for field in lb_mdo._get_ontology()]
     return lb_mdo, lb_metadata_names
 
@@ -60,7 +60,8 @@ def sync_metadata_fields(lb_client, spark_table, metadata_index={}):
             enum_options = get_unique_values(spark_table, metadata_field_name) if metadata_type == "enum" else []
             lb_mdo.create_schema(name=metadata_field_name, kind=conversion[metadata_type], options=enum_options)
             lb_mdo, lb_metadata_names = refresh_metadata_ontology(lb_client)
-    return spark_table
+    return_value = spark_table if spark_table else True            
+    return return_value
 
 def __create_upload_data_row_values(row_data_col, global_key_col, external_id_col, metadata_name_key_to_schema_bytes):
     """ Function to-be-wrapped into a pyspark UDF that will create data row dict values (without metadata)
@@ -139,7 +140,7 @@ def create_uploads_column(lb_client, spark_table, row_data_col, global_key_col,
         StructField("metadata_fields", ArrayType(MapType(StringType(), StringType(), True)))
     ])            
     # Set your udf variables
-    metadata_name_key_to_schema = get_metadata_schema_to_name_key(self.lb_client.get_data_row_metadata_ontology(), invert=True)
+    metadata_name_key_to_schema = get_metadata_schema_to_name_key(lb_client.get_data_row_metadata_ontology(), invert=True)
     # Run your __create_upload_data_row_values UDF, creating a new table in the process
     data_row_udf = udf(__create_upload_data_row_values, upload_schema)
     df = spark_dataframe.withColumn('uploads', data_row_udf(
